@@ -31,7 +31,13 @@ our $DEBUG = 0 ;
 
 =cut
 
-our %CONSTANTS ;
+our %CONSTANTS = () ;
+
+#-----------------------------------------------------------------------------
+sub _no_once_warning
+{
+	return \%CONSTANTS ;
+}
 
 # ============================================================================================
 # END OF PACKAGE
